@@ -1,7 +1,7 @@
 /*
  * Copyright 2005-2010 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
- * $Header: /var/cvsroot/gentoo-projects/portage-utils/qgrep.c,v 1.30 2011/10/03 01:25:54 vapier Exp $
+ * $Header: /var/cvsroot/gentoo-projects/portage-utils/qgrep.c,v 1.31 2012/08/13 22:23:35 robbat2 Exp $
  *
  * Copyright 2005-2010 Ned Ludd        - <solar@gentoo.org>
  * Copyright 2005-2010 Mike Frysinger  - <vapier@gentoo.org>
@@ -47,7 +47,7 @@ static const char * const qgrep_opts_help[] = {
 	"Print <arg> lines of trailing context",
 	COMMON_OPTS_HELP
 };
-static const char qgrep_rcsid[] = "$Id: qgrep.c,v 1.30 2011/10/03 01:25:54 vapier Exp $";
+static const char qgrep_rcsid[] = "$Id: qgrep.c,v 1.31 2012/08/13 22:23:35 robbat2 Exp $";
 #define qgrep_usage(ret) usage(ret, QGREP_FLAGS, qgrep_long_opts, qgrep_opts_help, lookup_applet_idx("qgrep"))
 
 char qgrep_name_match(const char*, const int, depend_atom**);
@@ -444,7 +444,7 @@ int qgrep_main(int argc, char **argv)
 				continue;
 
 		if ((newfp = fopen(ebuild, "r")) != NULL) {
-			unsigned int lineno = 0;
+			int lineno = 0;
 			char remaining_after_context = 0;
 			count = 0;
 			/* if there have been some matches already, then a separator will be needed */
